# Technical Debt Registry
| DEBT-E2E-STORY-005 | E2E tests pending - Reporting engine depends on full suite of metrics (including deferred STORY-004). | requirements/STORY-005.md | - | MEDIUM | Open | Tester (capability check) | 2025-12-29 |

| ID | Description | File | Line | Severity | Status | Found By | Date |
|:---|:---|:---|:---|:---|:---|:---|:---|
| DEBT-E2E-STORY-004 | E2E tests pending - Deferred complex analytics and reporting due to complexity and need for external embedding models/dependencies better handled in a focused session. | requirements/STORY-004.md | - | MEDIUM | Open | Tester (capability check) | 2025-12-29 |
